##  Prerequisites
Virtual workspaces only work with SSO configured for your SAP LeanIX:
  * Make sure that users are authenticated via SSO from your IdP, meaning the access to SAP LeanIX is managed by your IdP.
  * Make sure that users are authorized via SSO, meaning your IdP sends the user roles (viewer, member, admin).
  * Make sure you can add attributes to the SSO configuration. You need to be able to do this in later steps of the configuration. If you are not able to do this, reach out to the administrator of your IdP for the configuration.


To learn more, see [Single Sign-On](https://help.sap.com/docs/leanix/ea/single-sign-on-sso?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to configure single sign-on \(SSO\) with SAP LeanIX.").
